@@ -6,14 +6,11 @@ import inspect
 import functools
 import warnings
 from textwrap import dedent
-from itertools import combinations
-from collections import namedtuple
 from collections.abc import Iterable, Iterator, Collection
 
 import numpy as np
 import pandas as pd
-import networkx as nx
-from scipy.spatial import cKDTree
+
 
 #
 # Import the notebook-aware version of tqdm if
@@ -360,153 +357,3 @@ class _iter_batches_with_len(_iter_batches):
         return int(np.ceil(len(self.base_iterator) / self.batch_size))
 
 
-def skeleton_df_to_nx(df, with_attributes=True, directed=True):
-    """
-    Convert a skeleton DataFrame into a ``networkx`` graph.
-
-    Args:
-        df:
-            DataFrame as returned by :py:meth:`.Client.fetch_skeleton()`
-
-        with_attributes:
-            If True, store node attributes for x, y, z, radius
-
-        directed:
-            If True, return ``nx.DiGraph``, otherwise ``nx.Graph``.
-
-    Returns:
-        ``nx.DiGraph`` or ``nx.Graph``
-    """
-    if directed:
-        g = nx.DiGraph()
-    else:
-        g = nx.Graph()
-
-    if with_attributes:
-        for row in df.itertuples(index=False):
-            g.add_node(row.rowId, x=row.x, y=row.y, z=row.z, radius=row.radius)
-            if row.link != -1:
-                g.add_edge(row.link, row.rowId)
-    else:
-        df = df[['rowId', 'link']].sort_values(['rowId', 'link'])
-        g.add_nodes_from(df['rowId'].sort_values())
-        g.add_edges_from(df.query('link != -1').values)
-
-    return g
-
-
-def skeleton_df_to_swc(df, export_path=None):
-    """
-    Convert a skeleton DataFrame into a the text of an SWC file.
-
-    Args:
-        df:
-            DataFrame, as returned by :py:meth:`.Client.fetch_skeleton()`
-
-        export_path:
-            Optional. Write the SWC file to disk a the given location.
-
-    Returns:
-        string
-    """
-    df['node_type'] = 0
-    df = df[['rowId', 'node_type', 'x', 'y', 'z', 'radius', 'link']]
-    swc = "# "
-    swc += df.to_csv(sep=' ', header=True, index=False)
-
-    if export_path:
-        with open(export_path, 'w') as f:
-            f.write(swc)
-
-    return swc
-
-
-def heal_skeleton(skeleton_df):
-    """
-    Ensure a skeleton consists of a single connected component.
-
-    Rather than a single tree, skeletons from neuprint sometimes
-    consist of multiple fragments, i.e. multiple connected
-    components.  That's due to artifacts in the underlying
-    segmentation from which the skeletons were generated.
-    In such skeletons, there will be multiple 'root' nodes
-    (SWC rows where ``link == -1``).
-
-    This function 'heals' a fragmented skeleton by joining its
-    fragments into a single tree.
-
-    First, each fragment is joined to every other fragment at
-    their nearest points. The resulting graph has unnecessary
-    edges, which are then removed by extracting the minimum
-    spanning tree.  The MST is returned as the healed skeleton.
-
-    Args:
-        skeleton_df:
-            DataFrame as returned by :py:meth:`.Client.fetch_skeleton()`
-
-    Returns:
-        DataFrame, with ``link`` column updated with updated edges.
-    """
-    skeleton_df = skeleton_df.sort_values('rowId').reset_index(drop=True)
-    g = skeleton_df_to_nx(skeleton_df, False, False)
-
-    # Extract each fragment's rows and construct a KD-Tree
-    Fragment = namedtuple('Fragment', ['frag_id', 'df', 'kd'])
-    fragments = []
-    for frag_id, cc in enumerate(nx.connected_components(g)):
-        if len(cc) == len(skeleton_df):
-            # There's only one component -- no healing necessary
-            return skeleton_df
-
-        df = skeleton_df.query('rowId in @cc')
-        kd = cKDTree(df[[*'xyz']].values)
-        fragments.append( Fragment(frag_id, df, kd) )
-
-    # Sort from big-to-small, so the calculations below use a
-    # KD tree for the larger point set in every fragment pair.
-    fragments = sorted(fragments, key=lambda frag: -len(frag.df))
-
-    # We could use the full graph and connect all
-    # fragment pairs at their nearest neighbors,
-    # but it's faster to treat each fragment as a
-    # single node and run MST on that quotient graph,
-    # which is tiny.
-    frag_graph = nx.Graph()
-    for frag_a, frag_b in combinations(fragments, 2):
-        coords_b = frag_b.df[[*'xyz']].values
-        distances, indexes = frag_a.kd.query(coords_b)
-
-        index_b = np.argmin(distances)
-        index_a = indexes[index_b]
-
-        node_a = frag_a.df['rowId'].iloc[index_a]
-        node_b = frag_b.df['rowId'].iloc[index_b]
-        dist_ab = distances[index_b]
-
-        # Add edge from one fragment to another,
-        # but keep track of which fine-grained skeleton
-        # nodes were used to calculate distance.
-        frag_graph.add_edge( frag_a.frag_id, frag_b.frag_id,
-                             node_a=node_a, node_b=node_b,
-                             distance=dist_ab )
-
-    # Compute inter-fragment MST edges
-    frag_edges = nx.minimum_spanning_edges(frag_graph, weight='distance', data=True)
-
-    # For each inter-fragment edge, add the corresponding
-    # fine-grained edge between skeleton nodes in the original graph.
-    for _u, _v, d in frag_edges:
-        g.add_edge(d['node_a'], d['node_b'])
-
-    # Traverse in depth-first order to compute final tree
-    root = skeleton_df['rowId'].iloc[0]
-    edges = list(nx.dfs_edges(g, source=root))
-    edges = pd.DataFrame(edges, columns=['link', 'rowId']) # parent, child
-    edges = edges.set_index('rowId')['link']
-
-    # Replace 'link' (parent) column using MST edges
-    skeleton_df['link'] = skeleton_df['rowId'].map(edges).fillna(-1).astype(int)
-    assert (skeleton_df['link'] == -1).sum() == 1
-    assert skeleton_df['link'].iloc[0] == -1
-
-    return skeleton_df
